@@ -58,7 +58,6 @@ loaded.
 
 sub load {
     my ($self,$force) = @_;
-    $force = $self->{force_load} unless defined($force);
     my $meta_json;
     my $cached = undef;
     if (!$force) {
@@ -74,18 +73,6 @@ sub load {
     return $self;
 }
 
-=item $meta->initialized()
-
-Returns C<true> if the meta data has been initialized, either by loading it or 
-by using a cached data. If false the data can be loaded via L<load>
-
-=cut 
-
-sub initialized {
-    my $self = shift;
-    return defined($self->{_meta});
-}
-
 =item $value = $meta->get($key)
 
 Get a value from the meta data. 
@@ -116,7 +103,7 @@ sub latest_matching_version {
         my $range = $version_info->{$v}->{jmx4perl};
         if ($range) {
             my $match = $self->_check_version($jmx4perl_version,$range);
-            #print "Match: $match for $range (j4p: $jmx4perl_version)\n";
+            print "Match: $match for $range (j4p: $jmx4perl_version)\n";
             return $v if $match;
         }
     }
@@ -292,9 +279,7 @@ sub _load_from_server {
         return from_json($content, {utf8 => 1});
     }
     else {
-        # Log an error, but do not exit ...
-        $self->{logger}->error("Cannot load Jolokia Meta-Data from $JOLOKIA_META_URL: " . $response->status_line);
-        return undef;
+        $self->_fatal("Cannot load Jolokia Meta-Data from $JOLOKIA_META_URL: " . $response->status_line);
     }
 }
 
